=============
Pydeformation
=============

This is a wrapper around Sebastian Pancratz deformation code.

To use this module, you need to import it:: 

    from pydeformation import *

This work is licensed under a `Creative Commons Attribution-Share Alike
3.0 License`__.

__ https://creativecommons.org/licenses/by-sa/3.0/

Pydeformation
=============

.. toctree::
   :maxdepth: 1

   deformation


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
